==> web-fw2_2_2.zip: web-fw2_2_2/j2src/weber/org/itscool/weber/user/UserUtil.java <==
package org.itscool.weber.user;

import java.io.IOException;
import java.util.List;

import org.itscool.commons.bean.BeanFactory;

/**
 * [UɊւ郆[eBeBNX
 */
public class UserUtil {
	/**
	 * [U̎擾
	 * @param userName [U
	 * @return [U
	 */
	public static List getAllData(){
		BeanFactory factory = BeanFactory.getInstance();
        RoleManager mgr = (RoleManager)factory.createInstance("RoleManager");
        return mgr.getAllData();
	}
	/**
	 * [U̎擾
	 * @param userName [U
	 * @return [U
	 */
	public static User getUser(String userName){
		BeanFactory factory = BeanFactory.getInstance();
        RoleManager mgr = (RoleManager)factory.createInstance("RoleManager");
        return mgr.getUser("guest1", userName);
	}
	
    /**
     * [U̍폜
     * @param user [U
    */
    public static void deleteUser(User user)
    throws IOException{
    	BeanFactory factory = BeanFactory.getInstance();
        RoleManager mgr = (RoleManager)factory.createInstance("RoleManager");
        mgr.delete("guest", user);
    }
    
	/**
	 * [U̒ǉ
     * @param user [U
	 */
	public static  boolean insertUser(User user)
	throws IOException{
		BeanFactory factory = BeanFactory.getInstance();
        RoleManager mgr = (RoleManager)factory.createInstance("RoleManager");
        return mgr.add("guest", user);
	}
	
	/**
	 * [U̍XV
     * @param user [U
	 */
	public static void updateUser(User user)
	throws IOException{
		BeanFactory factory = BeanFactory.getInstance();
        RoleManager mgr = (RoleManager)factory.createInstance("RoleManager");
        mgr.update("guest", user);
	}
}

==> web-fw3_0_2.zip: web-fw3_0_2/j2src/weber/org/itscool/weber/user/UserUtil.java <==
package org.itscool.weber.user;

import java.io.IOException;
import java.util.List;

import org.itscool.commons.bean.BeanFactory;

/**
 * [UɊւ郆[eBeBNX
 */
public class UserUtil {
	/**
	 * [U̎擾
	 * @param userName [U
	 * @return [U
	 */
	public static List getAllData(){
		BeanFactory factory = BeanFactory.getInstance();
        RoleManager mgr = (RoleManager)factory.createInstance("RoleManager");
        return mgr.getAllData();
	}
	/**
	 * [U̎擾
	 * @param userName [U
	 * @return [U
	 */
	public static User getUser(String roleName, String userName){
		BeanFactory factory = BeanFactory.getInstance();
        RoleManager mgr = (RoleManager)factory.createInstance("RoleManager");
        return mgr.getUser(roleName, userName);
	}
	
    /**
     * [U̍폜
     * @param user [U
    */
    public static void deleteUser(String roleName, User user)
    throws IOException{
    	BeanFactory factory = BeanFactory.getInstance();
        RoleManager mgr = (RoleManager)factory.createInstance("RoleManager");
        mgr.delete(roleName, user);
    }
    
	/**
	 * [U̒ǉ
     * @param user [U
	 */
	public static  boolean insertUser(String roleName, User user)
	throws IOException{
		BeanFactory factory = BeanFactory.getInstance();
        RoleManager mgr = (RoleManager)factory.createInstance("RoleManager");
        return mgr.add(roleName, user);
	}
	
	/**
	 * [U̍XV
     * @param user [U
	 */
	public static void updateUser(String roleName, User user)
	throws IOException{
		BeanFactory factory = BeanFactory.getInstance();
        RoleManager mgr = (RoleManager)factory.createInstance("RoleManager");
        mgr.update(roleName, user);
	}
}
